#include <algorithm>
#include <array>
#include <cassert>
#include <cstdint>
#include <iostream>
#include <string>
#include <string_view>
#include <vector>

// rows, columns, and prefix of columns that are rotated by the last move
constexpr int32_t R = 3;
constexpr int32_t C = 10;
constexpr int32_t M = 3;
constexpr int32_t N = R * C;
using State = std::array<int32_t, N>;

constexpr State GOAL = []() {
    State res{};
    for (int32_t i = 0; i < N; ++i)
        res[i] = i / C;

    return res;
}();

constexpr std::array<int32_t, R * M> CENTER_IDXS = []() {
    std::array<int32_t, R * M> res{};
    for (int32_t i = 0; i < R; ++i) {
        for (int32_t j = 0; j < M; ++j) {
            res[M * i + j] = C * i + j;
        }
    }

    return res;
}();

int32_t parse(char c) {
    switch (c) {
        case 'o':
            return 0;
        case 'g':
            return 1;
        case 'r':
            return 2;
        default:
            break;
    }
    assert(false);
    return -1;
}

State runMove(State state, int32_t ring, int32_t iters) {
    if (ring == R) {
        iters *= M;
        for (int32_t k = 0; k < iters; ++k) {
            char c = state[CENTER_IDXS[0]];
            for (int32_t i = 0; i + 1 < R * M; ++i) {
                state[CENTER_IDXS[i]] = state[CENTER_IDXS[i + 1]];
            }

            state[CENTER_IDXS[R * M - 1]] = c;
        }
    } else {
        auto start = state.begin() + ring * C;
        auto end = start + C;

        std::rotate(start, start + (C - iters), end);
    }

    return state;
}

// for debugging only
std::ostream& operator<<(std::ostream& os, const State& state) {
    for (int32_t i = 0; i < R; ++i) {
        for (int32_t j = 0; j < C; ++j) {
            os << "ogr"[state[C * i + j]];
        }
        os << '\n';
    }
    return os;
}

int32_t indexOf(const State& state, int32_t ring, int32_t val) {
    auto start = state.begin() + ring * C;
    auto end = start + C;

    return std::find(start, end, val) - start;
}

int main() {
    State cur;
    for (int32_t i = 0; i < R; ++i) {
        std::string row;
        std::cin >> row;
        for (int32_t j = 0; j < C; ++j) {
            cur[C * i + j] = parse(row[j]);
        }
    }

    std::vector<std::array<int32_t, 2>> solution;
    auto run = [&](int32_t ring, int32_t iters) {
        solution.push_back({ring, iters});
        cur = runMove(cur, ring, iters);
    };

    bool foundSwap = true;
    while (foundSwap && solution.size() < 800 && cur != GOAL) {
        foundSwap = false;
        for (int32_t i1 = 0; i1 < R; ++i1) {
            int32_t i2 = (i1 + 1) % R;
            int32_t j1 = indexOf(cur, i1, i2);
            int32_t j2 = indexOf(cur, i2, i1);

            if (j1 == C || j2 == C) {
                continue;
            }

            if (j1 != 0) {
                run(i1, C - j1);
            }

            if (j2 != M) {
                run(i2, (M + C - j2) % C);
            }

            run(R, 2);
            run(i2, 9);
            run(R, 1);

            foundSwap = true;
        }

        if (!foundSwap) {
            // 3-cycle
            static constexpr std::array<int32_t, R> NEED{M, C - 1, 0};
            for (int32_t offset = 1; offset <= 2; ++offset) {
                std::array<int32_t, R> idxs{C, C, C};
                for (int32_t i = 0; i < R; ++i) {
                    idxs[i] = indexOf(cur, i, (i + offset) % R);
                }

                if (std::any_of(idxs.begin(), idxs.end(), [](int32_t x){ return x == C; })) {
                    continue;
                }

                for (int32_t i = 0; i < R; ++i) {
                    if (idxs[i] != NEED[i]) {
                        run(i, (NEED[i] + C - idxs[i]) % C);
                    }
                }

                run(R, 2);
                run(0, C - 1);
                run(R, 2);
                run(1, 1);
                run(R, 2);

                foundSwap = true;
                break;
            }
        }

        assert(foundSwap);
    }

    std::cout << solution.size() << '\n';
    for (auto [k, v] : solution) {
        std::cout << "ogrc"[k] << v << '\n';
    }

    return 0;
}
